#!/bin/bash

# Code for SCRIPT_DIR adapted from https://stackoverflow.com/questions/59895/how-can-i-get-the-source-directory-of-a-bash-script-from-within-the-script-itsel
SCRIPT_DIR=$( cd -- "$( dirname -- "${BASH_SOURCE[0]}" )" &> /dev/null && pwd )

PULSAR_VERSION=2.10.0
PULSAR_DIR=~/pulsar
CONF_DIR=$PULSAR_DIR/conf
DATA_DIR=$PULSAR_DIR/data
ZOOKEEPER_DATA_DIR=$DATA_DIR/zookeeper
PULSAR_LOGS_DIR=$PULSAR_DIR/logs

echo "PULSAR_VERSION=$PULSAR_VERSION"
echo "PULSAR_DIR=$PULSAR_DIR"
echo "CONF_DIR=$CONF_DIR"
echo "DATA_DIR=$DATA_DIR"
echo "ZOOKEEPER_DATA_DIR=$ZOOKEEPER_DATA_DIR"

echo "Installing Java"
sudo apt install default-jre

echo "Creating Pulsar directory $PULSAR_DIR"
mkdir $PULSAR_DIR
cd $PULSAR_DIR

echo "Creating logs directory $PULSAR_LOGS_DIR"
mkdir $PULSAR_LOGS_DIR

echo "Downloading Pulsar $PULSAR_VERSION files to $PULSAR_DIR"
wget https://archive.apache.org/dist/pulsar/pulsar-$PULSAR_VERSION/apache-pulsar-$PULSAR_VERSION-bin.tar.gz

echo "Un-taring Pulsar Files into $PULSAR_DIR"
tar xvfz apache-pulsar-$PULSAR_VERSION-bin.tar.gz

echo "Removing Pulsar tar"
rm apache-pulsar-$PULSAR_VERSION-bin.tar.gz

echo "Creating data directory at $DATA_DIR and config directory at $CONF_DIR" 
mkdir -p $DATA_DIR
mkdir -p $CONF_DIR

cp -r ~/pulsar/apache-pulsar-$PULSAR_VERSION/conf $PULSAR_DIR

echo "Copying Zookeeper configuration to $CONF_DIR"
cp $SCRIPT_DIR/pulsar/conf/zk1.properties $CONF_DIR && echo "Configuration for Zookeeper 1 copied"   
cp $SCRIPT_DIR/pulsar/conf/zk2.properties $CONF_DIR && echo "Configuration for Zookeeper 2 copied" 
cp $SCRIPT_DIR/pulsar/conf/zk3.properties $CONF_DIR && echo "Configuration for Zookeeper 3 copied" 

echo "Making data directories for zookeepers at $ZOOKEEPER_DATA_DIR"
mkdir -p $ZOOKEEPER_DATA_DIR

echo "Creating directory $ZOOKEEPER_DATA_DIR/zk1"
mkdir $ZOOKEEPER_DATA_DIR/zk1 && echo "Directory created succesfully" 

echo "Creating directory $ZOOKEEPER_DATA_DIR/zk2"
mkdir $ZOOKEEPER_DATA_DIR/zk2 && echo "Directory created succesfully" 

echo "Creating directory $ZOOKEEPER_DATA_DIR/zk3"
mkdir $ZOOKEEPER_DATA_DIR/zk3 && echo "Directory created succesfully"

echo 1 > $ZOOKEEPER_DATA_DIR/zk1/myid
echo 2 > $ZOOKEEPER_DATA_DIR/zk2/myid
echo 3 > $ZOOKEEPER_DATA_DIR/zk3/myid

echo "Copying Global Zookeeper configuration to $CONF_DIR"
cp $SCRIPT_DIR/pulsar/conf/global_zookeeper.conf $CONF_DIR && echo "Configurations for Global Zookeeper copied"

echo "Copying Bookkeeper configuration to $CONF_DIR"
cp $SCRIPT_DIR/pulsar/conf/book1.properties $CONF_DIR && echo "Configurations for Bookkeeper 1 copied"
cp $SCRIPT_DIR/pulsar/conf/book2.properties $CONF_DIR && echo "Configurations for Bookkeeper 2 copied"

echo "Copying Broker configuration to $CONF_DIR"
cp $SCRIPT_DIR/pulsar/conf/pb1.properties $CONF_DIR && echo "Configurations for Broker 1 copied"
cp $SCRIPT_DIR/pulsar/conf/pb2.properties $CONF_DIR && echo "Configurations for Broker 2 copied"
cp $SCRIPT_DIR/pulsar/conf/pb3.properties $CONF_DIR && echo "Configurations for Broker 3 copied"

echo "Success"
