#!/bin/bash
PULSAR_VERSION_NUMBER=2.10.0
CLUSTER_NAME="sample-cluster"

PULSAR_DIR=~/pulsar
PULSAR_CONF_DIR=$PULSAR_DIR/conf
PULSAR_LOG_DIR=$PULSAR_DIR/logs

PULSAR_SCRIPT=$PULSAR_DIR/apache-pulsar-$PULSAR_VERSION_NUMBER/bin/pulsar

echo "Starting local Pulsar Cluster..."

echo "Starting Zookeeper agents"
(export PULSAR_ZK_CONF=$PULSAR_CONF_DIR/zk1.properties; nohup $PULSAR_SCRIPT zookeeper &>$PULSAR_LOG_DIR/zk1.txt &) 
(export PULSAR_ZK_CONF=$PULSAR_CONF_DIR/zk2.properties; nohup $PULSAR_SCRIPT zookeeper &>$PULSAR_LOG_DIR/zk2.txt &)
(export PULSAR_ZK_CONF=$PULSAR_CONF_DIR/zk3.properties; nohup $PULSAR_SCRIPT zookeeper &>$PULSAR_LOG_DIR/zk3.txt &)

echo "Starting global Zookeeper"
(export PULSAR_ZK_CONF=$PULSAR_CONF_DIR/global_zookeeper.conf; nohup $PULSAR_SCRIPT zookeeper &>$PULSAR_LOG_DIR/global_zk.txt &)

echo "Initializing cluster metadata"
$PULSAR_SCRIPT initialize-cluster-metadata --cluster $CLUSTER_NAME --zookeeper localhost:2181 --configuration-store localhost:2184 --web-service-url http://localhost:8090/ --broker-service-url pulsar://localhost:6650/

echo "Starting Bookkeeper agents"
(export PULSAR_BOOKKEEPER_CONF=$PULSAR_CONF_DIR/book1.properties; nohup $PULSAR_SCRIPT bookie &>$PULSAR_LOG_DIR/book1.txt &)
(export PULSAR_BOOKKEEPER_CONF=$PULSAR_CONF_DIR/book2.properties; nohup $PULSAR_SCRIPT bookie &>$PULSAR_LOG_DIR/book2.txt &)

echo "Starting Pulsar broker agents"
(export PULSAR_BROKER_CONF=$PULSAR_CONF_DIR/pb1.properties; nohup $PULSAR_SCRIPT broker &>$PULSAR_LOG_DIR/pb1.txt &)
(export PULSAR_BROKER_CONF=$PULSAR_CONF_DIR/pb2.properties; nohup $PULSAR_SCRIPT broker &>$PULSAR_LOG_DIR/pb2.txt &)
(export PULSAR_BROKER_CONF=$PULSAR_CONF_DIR/pb3.properties; nohup $PULSAR_SCRIPT broker &>$PULSAR_LOG_DIR/pb3.txt &)

echo "Success, cluster started"
